--- openflow-2011-03-31.h	2015-07-23 09:54:16.532479337 -0700
+++ openflow-2011-03-31-2.h	2015-07-23 09:54:16.540479337 -0700
@@ -341,7 +341,8 @@
 /* Why is this packet being sent to the controller? */
 enum ofp_packet_in_reason {
     OFPR_NO_MATCH,          /* No matching flow. */
-    OFPR_ACTION             /* Action explicitly output to controller. */
+    OFPR_ACTION,            /* Action explicitly output to controller. */
+    OFPR_INVALID_TTL        /* Packet has invalid TTL */
 };
 
 /* Packet received on port (datapath -> controller). */
